var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { JumboObject } from '../base/jumboObject';
export class List extends JumboObject {
    /**
     * Returns all of your lists (login required)
     */
    getMyLists(headers, query) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.jumbo.get(`lists/mylists`, headers, query, true);
        });
    }
    /**
     * Returns a single list given a list ID
     * @param listId ID of list
     */
    getListFromId(listId, headers, query) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.jumbo.get(`lists/${listId}`, headers, query, false);
        });
    }
    /**
     * Returns a list of lists that match the given name (name is case sensitive and very specific)
     * @param listName Name of list (category)
     * @param offset Offset in search (default 0)
     * @param limit Amount of lists to retrieve (default 10)
     */
    getListsByName(listName, offset, limit, headers, query) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.jumbo.get(`lists/search`, headers, Object.assign({ offset: (offset ? offset : 0).toString(), limit: (limit ? limit : 10).toString(), q: listName }, query), false);
        });
    }
    /**
     * Shortcut function to get the most popular lists
     * @param offset Offset in search (default 0)
     * @param limit Amount of lists to retrieve (default 10)
     */
    getPopularLists(offset, limit, headers, query) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.getListsByName('', offset, limit, headers, query);
        });
    }
    /**
     * Gets all items from a given list
     * @param listId ID of list
     * @param offset Offset in search (default 0)
     * @param limit Amount of items to retrieve (default 10)
     */
    getItemsFromList(listId, offset, limit, headers, query) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.jumbo.get(`lists/${listId}/items`, headers, Object.assign({ offset: (offset ? offset : 0).toString(), limit: (limit ? limit : 10).toString() }, query), false);
        });
    }
    /**
     * Gets all smart lists (i.e. last purchased) of user (login required)
     */
    getMySmartLists(headers, query) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.jumbo.get(`users/me/smart-lists`, headers, query, true);
        });
    }
    /**
     * Gets all the lists the user currently follows (login required)
     */
    getMyFollowedLists(headers, query) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.jumbo.get(`lists/following`, headers, query, true);
        });
    }
    /**
     * Checks whether the user is following the given list (login required)
     * @param listId ID of list
     */
    isFollowingList(listId, headers, query) {
        return __awaiter(this, void 0, void 0, function* () {
            const isFollowing = yield this.jumbo.get(`lists/${listId}/following`, headers, query, true);
            return isFollowing.isFollowing;
        });
    }
    /**
     * Makes the user follow the given list (login required)
     * @param listId ID of list to follow
     */
    followList(listId, headers, query) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.jumbo.put(`lists/${listId}/follow`, undefined, headers, query, true);
        });
    }
    /**
     * Makes the user unfollow the given list (login required)
     * @param listId ID of list to unfollow
     */
    unfollowList(listId, headers, query) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.jumbo.put(`lists/${listId}/unfollow`, undefined, headers, query, true);
        });
    }
}
