var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { JumboObject } from '../base/jumboObject';
export class Product extends JumboObject {
    /**
     * Gets product from ID
     * @param productId Product ID
     */
    getProductFromId(productId, headers, query) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.jumbo.get(`products/${productId}`, headers, query);
        });
    }
    /**
     * Get products from given product name
     * @param productName Product name to search for
     * @param offset Offset in search (default 0)
     * @param limit Amount of products returned (default 10)
     * @param filters Any extra filters (in the form of a number)
     * @param sort Sort options as defined in ./productModel
     */
    getProductsFromName(productName, offset, limit, filters, sort, headers, query) {
        return __awaiter(this, void 0, void 0, function* () {
            // First get query results as productQueryModel
            const products = yield this.jumbo.get(`search`, headers, Object.assign({ q: productName, offset: (offset ? offset : 0).toString(), limit: (limit ? limit : 10).toString(), filters: (filters ? filters : '').toString(), sort: (sort ? sort : '').toString() }, query));
            // Then create a ProductModel for every ProductQuery product
            const result = [];
            for (var key in products.products.data) {
                const product = {
                    product: {
                        data: products.products.data[key],
                    },
                };
                result.push(product);
            }
            // Return array of ProductModels
            return result;
        });
    }
    /**
     * Shortcut function to get the first product when searching for name
     * @param productName Product name to search for
     * @param sort Sort options as defined in ./productModel
     */
    getFirstProductFromName(productName, sort, headers, query) {
        return __awaiter(this, void 0, void 0, function* () {
            const product = yield this.getProductsFromName(productName, 0, 1, undefined, sort, headers, query);
            return product[0];
        });
    }
}
