var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { JumboObject } from '../base/jumboObject';
export class Recipe extends JumboObject {
    /**
     * Get recipe from ID
     * @param recipeId Recipe ID
     */
    getRecipeFromId(recipeId, headers, query) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.jumbo.get(`recipes/${recipeId}`, headers, query);
        });
    }
    /**
     * Get recipes from given recipe name
     * @param recipeName Recipe name to search for
     * @param offset Offset in search (default 0)
     * @param count Amount of recipes returned (default 10)
     */
    getRecipesFromName(recipeName, offset, count, headers, query) {
        return __awaiter(this, void 0, void 0, function* () {
            const recipes = yield this.jumbo.get(`recipes`, headers, Object.assign({ q: recipeName, offset: (offset ? offset : 0).toString(), limit: (count ? count : 10).toString() }, query));
            const result = [];
            for (var key in recipes.recipes.data) {
                const recipe = {
                    recipe: {
                        data: recipes.recipes.data[key],
                    },
                };
                result.push(recipe);
            }
            return result;
        });
    }
    /**
     * Shortcut function to get the first recipe when searching for name
     * @param recipeName Recipe name to search for
     */
    getFirstRecipeFromName(recipeName, headers, query) {
        return __awaiter(this, void 0, void 0, function* () {
            const recipe = yield this.getRecipesFromName(recipeName, 0, 1, headers, query);
            return recipe[0];
        });
    }
    /**
     * Get recipes from given filter ID
     * @param filterId Recipe filter ID
     * @param offset Offset in search (default 0)
     * @param count Amount of recipes returned (default 10)
     */
    getRecipesFromFilterId(filterId, offset, count, headers, query) {
        return __awaiter(this, void 0, void 0, function* () {
            const recipes = yield this.jumbo.get(`recipes`, headers, Object.assign({ filterId: filterId.toString(), offset: (offset ? offset : 0).toString(), limit: (count ? count : 10).toString() }, query));
            const result = [];
            for (var key in recipes.recipes.data) {
                const recipe = {
                    recipe: {
                        data: recipes.recipes.data[key],
                    },
                };
                result.push(recipe);
            }
            return result;
        });
    }
}
