var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { JumboObject } from '../base/jumboObject';
export class Store extends JumboObject {
    /**
     * Gets store from store ID
     * @param storeId Store ID
     */
    getStoreFromId(storeId, headers, query) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.jumbo.get(`stores/${storeId}`, headers, query);
        });
    }
    /**
     * Find stores based on given longitude, latitude and distance (optional)
     * @param long Longitude
     * @param lat Latitude
     * @param distance Maximum search radius (default none)
     * @param count Number of stores to retrieve (default 20)
     * @param offset Offset in search (default 0)
     */
    getStoresFromLongLat(long, lat, distance, count, offset, headers, query) {
        return __awaiter(this, void 0, void 0, function* () {
            const stores = yield this.jumbo.get(`stores`, headers, Object.assign({ longitude: long.toString(), latitude: lat.toString(), distance: (distance ? distance : '').toString(), count: (count ? count : 20).toString(), offset: (offset ? offset : 0).toString() }, query));
            const result = [];
            for (var key in stores.stores.data) {
                const store = {
                    store: {
                        data: stores.stores.data[key],
                    },
                };
                result.push(store);
            }
            return result;
        });
    }
    /**
     * Shortcut function to get the nearest store given longitude and latitude
     * @param long Longitude
     * @param lat Latitude
     */
    getNearestStoreFromLongLat(long, lat, headers, query) {
        return __awaiter(this, void 0, void 0, function* () {
            const stores = yield this.getStoresFromLongLat(long, lat, undefined, undefined, undefined, headers, query);
            return stores[0];
        });
    }
}
